diff --git a/source/config/__init__.py b/source/config/__init__.py
index c02396d..091970a 100644
--- a/source/config/__init__.py
+++ b/source/config/__init__.py
@@ -616,7 +616,7 @@ class ConfigManager(object):
 		self.rootSection = None
 		self._initBaseConf(factoryDefaults=factoryDefaults)
 
-	def createProfile(self, name):
+	def createProfile(self, name, parentProfile=None):
 		"""Create a profile.
 		@param name: The name of the profile ot create.
 		@type name: basestring
@@ -627,8 +627,16 @@ class ConfigManager(object):
 		fn = self._getProfileFn(name)
 		if os.path.isfile(fn):
 			raise ValueError("A profile with the same name already exists: %s" % name)
-		# Just create an empty file to make sure we can.
-		file(fn, "w")
+		# Create an empty file and if there is parent profile - copy its settings to the new file.
+		with open(fn, "w") as npfp:
+			if parentProfile:
+				parent = self._getProfileFn(parentProfile)
+				if not os.path.isfile(parent):
+					log.debug("Parent profile %s does not exist"%parent)
+					return
+				with open(parent, 'r') as ppfp:
+					for line in ppfp:
+						npfp.write(line)
 
 	def deleteProfile(self, name):
 		"""Delete a profile.
diff --git a/source/gui/configProfiles.py b/source/gui/configProfiles.py
index 4be9f10..3bee480 100644
--- a/source/gui/configProfiles.py
+++ b/source/gui/configProfiles.py
@@ -370,6 +370,7 @@ class NewProfileDialog(wx.Dialog):
 		sizer.Add(item)
 		mainSizer.Add(sizer)
 
+		sizer = wx.BoxSizer(wx.HORIZONTAL)
 		# Translators: The label of a radio button to specify that a profile will be used for manual activation
 		# in the new configuration profile dialog.
 		self.triggers = triggers = [(None, _("Manual activation"), True)]
@@ -377,9 +378,23 @@ class NewProfileDialog(wx.Dialog):
 		item = self.triggerChoice = wx.RadioBox(self, label=_("Use this profile for:"),
 			choices=[trig[1] for trig in triggers])
 		item.Bind(wx.EVT_RADIOBOX, self.onTriggerChoice)
+		sizer.Add(item)
 		self.autoProfileName = ""
 		self.onTriggerChoice(None)
-		mainSizer.Add(item)
+		mainSizer.Add(sizer)
+
+		copySettingsSizer=wx.BoxSizer(wx.HORIZONTAL)
+		# Translators: The label for a combo box in the New profile dialog to select a profile which settings to be copied to the newly created profile.
+		copySettingsLabel=wx.StaticText(self,-1,label=_("&Copy settings from:"))
+		copySettingsSizer.Add(copySettingsLabel)
+		copySettingsListID=wx.NewId()
+		self.copyChoises=[_("None")]
+		self.copyChoises.extend([parent.getProfileDisplay(name) for name in parent.profileNames][1:])
+		# Translators: A combo box to choose configuration profile.
+		self.copySettingsList=wx.Choice(self,copySettingsListID,name=_("Copy settings from"),choices=self.copyChoises)
+		self.copySettingsList.SetSelection(0)
+		copySettingsSizer.Add(self.copySettingsList)
+		mainSizer.Add(copySettingsSizer)
 
 		mainSizer.Add(self.CreateButtonSizer(wx.OK | wx.CANCEL))
 		self.Bind(wx.EVT_BUTTON, self.onOk, id=wx.ID_OK)
@@ -404,8 +419,10 @@ class NewProfileDialog(wx.Dialog):
 		name = api.filterFileName(self.profileName.Value)
 		if not name:
 			return
+		copyChoise=self.copySettingsList.GetSelection()
+		parentProfile = api.filterFileName(self.copyChoises[copyChoise]) if copyChoise>0 else None
 		try:
-			config.conf.createProfile(name)
+			config.conf.createProfile(name, parentProfile)
 		except ValueError:
 			# Translators: An error displayed when the user attempts to create a configuration profile which already exists.
 			gui.messageBox(_("That profile already exists. Please choose a different name."),
diff --git a/user_docs/en/userGuide.t2t b/user_docs/en/userGuide.t2t
index 6fbdc54..f254944 100644
--- a/user_docs/en/userGuide.t2t
+++ b/user_docs/en/userGuide.t2t
@@ -1153,6 +1153,7 @@ If you only want to use this profile manually, select Manual activation, which i
 Otherwise, select a trigger which should automatically activate this profile.
 For convenience, if you haven't entered a name for the profile, selecting a trigger will fill in the name accordingly.
 See [below #ConfigProfileTriggers] for more information about triggers.
+If you want to create a profile, very similar to an existing one, you can copy the settings from the existing profile into the new one by selecting it from the "Copy settings from" combo box.
 
 Pressing OK will create the profile and close the Configuration Profiles dialog so you can edit it.
 
